package de.bfpi.kg;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.jbpm.api.NewDeployment;
import org.jbpm.api.ProcessInstance;
import org.jbpm.api.task.Task;
import org.jbpm.test.JbpmTestCase;

public class AllgemeinTest extends JbpmTestCase {

	protected void setUp() throws Exception {
		
		super.setUp();
		
		/* Prozessmodell einbinden und deployen */
		
		NewDeployment deployment = repositoryService.createDeployment();
		deployment.addResourceFromClasspath("allgemein.bpmn.xml");
		deployment.addResourceFromClasspath("messwert.ftl");
		String deploymentId = deployment.deploy();
		registerDeployment(deploymentId);
		
		/* Beispielnutzer anlegen */
		
		identityService.createGroup("techniker");
		identityService.createUser("tech1", "Alan", "Turing");
		identityService.createMembership("tech1", "techniker");
		
	}
	
	protected void tearDown() throws Exception {
		identityService.deleteUser("tech1");
		identityService.deleteGroup("techniker");
		super.tearDown();
	}
	
	public void testPfad1(){
		/* Prozess starten */ 
		ProcessInstance pi = executionService.startProcessInstanceByKey("allgemein");
		
		/* userTasks für Alan Turin abfragen */
		List<Task> tasks = taskService.findGroupTasks("tech1");
		assertEquals(1, tasks.size());
		
		/* Alan Turing übernimmt den Task */
		Task akt1 = tasks.get(0);
		assertEquals("Aktivität 1", akt1.getName());
		taskService.takeTask(akt1.getId(), "tech1");
		
		/* Alan Turing komplettiert den Task */
		Map<String, Object> variables = new HashMap<String, Object>();
		variables.put("wert", 5);
		variables.put("messwert", 10);
		taskService.completeTask(akt1.getId(), variables);
		
		/* Erneut Tasks abfragen */
		tasks = taskService.findGroupTasks("tech1");
		assertEquals(1, tasks.size());
		
		/* Alan Turing übernimmt und komplettiert erneut */
		Task pfad1 = tasks.get(0);
		assertEquals("Pfad 1", pfad1.getName());
		taskService.takeTask(pfad1.getId(), "tech1");
		taskService.completeTask(pfad1.getId());
		
		tasks = taskService.findGroupTasks("tech1");
		System.out.println(pi.getExecutions());
		//executionService.endProcessInstance(pi.getId(), pi.getState());
		System.out.println(pi.getState());
		System.out.println(pi.findActiveActivityNames());
	}

}
